available.packages. If the argument path is supplied, then the function attempts to read from a local repository, otherwise attempts to read from a CRAN mirror at the repos url.pkgAvail(repos = getOption("repos"), type = "source", ...)available.packagesavailable.packagesavailable.packagesgetCranDescription;
pkgDep